#ifndef SPI_H_		// Header guard.
#define SPI_H_

/*------------------------------------------------------------------------------
  spi.h --
  
  Description:
    Provides function prototypes and macro definitions for utilizing the SPI
    system of the ATxmega128A1U. 
  
  Author(s): Dr. Eric M. Schwartz, Christopher Crary, Wesley Piard
  Last modified by: Dr. Eric M. Schwartz
  Last modified on: 28 Feb 2024
------------------------------------------------------------------------------*/

/********************************DEPENDENCIES**********************************/

#include <avr/io.h>

/*****************************END OF DEPENDENCIES******************************/

/***********************************MACROS*************************************/

#define SS_bm     (1<<?)
#define MOSI_bm	  (1<<?)
#define MISO_bm	  (1<<?)
#define SCK_bm    (1<<?)

/********************************END OF MACROS*********************************/

/*****************************FUNCTION PROTOTYPES******************************/

/*------------------------------------------------------------------------------
  spi_init -- 
  
  Description:
    Initializes the relevant SPI module to communicate with the LSM6DSL.

  Input(s): N/A
  Output(s): N/A
------------------------------------------------------------------------------*/
void spi_init(void);

/*------------------------------------------------------------------------------
  spi_write -- 
  
  Description:
    Transmits a single byte of data via the relevant SPI module.

  Input(s): `data` - 8-bit value to be written via the relevant SPI module. 
  Output(s): N/A
------------------------------------------------------------------------------*/
void spi_write(uint8_t data);

/*------------------------------------------------------------------------------
  spi_read -- 
  
  Description:
    Reads a byte of data via the relevant SPI module.

  Input(s): N/A
  Output(s): 8-bit value read from the relevant SPI module.
------------------------------------------------------------------------------*/
uint8_t spi_read(void);

/**************************END OF FUNCTION PROTOTYPES**************************/

#endif // End of header guard.